@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/06/08]    全テーブル名の取得関数追加
  -      [2007/03/11]    入力データのエスケープ処理指定を追加
  -      [2005/06/01]    コンストラクタ引数変更、DB接続オジェクトを追加
  -      [2005/05/11]    作成
@@ -38,13 +39,13 @@ class manip_sqlite
      * テーブル名
      * @var string
      */
-    var $tbl_name = "";
+    var $tbl_name = '';
 
     /**
-     * テーブル名
-     * @var string
+     * プライマリキー
+     * @var array
      */
-    var $primary_key = "";
+    var $primary = array();
 
     /**
      * コンストラクタ
@@ -60,6 +61,18 @@ class manip_sqlite
         $this->tbl_name = $tbl_name;
     }
 
+    /**
+     * テーブル名の設定
+     *
+     * @access public
+     * @param string $tbl_name
+     * @return void
+     */
+    function setTableName($tbl_name)
+    {
+        $this->tbl_name = $tbl_name;
+    }
+
     /**
      * プライマリキーの取得
      *
@@ -68,7 +81,34 @@ class manip_sqlite
      */
     function getPrimaryKey()
     {
-        return $this->primary_key;
+        return $this->primary['key'];
+    }
+
+    /**
+     * 全テーブル名の取得
+     *
+     * @access public
+     * @return array
+     */
+    function getTables()
+    {
+        $sql =
+            'SELECT '.
+                'name '.
+            'FROM '.
+                'sqlite_master '.
+            'WHERE '.
+                "type = 'table'";
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $list = array();
+        foreach ($result as $value){
+            $list[] = $value['name'];
+        }
+
+        return $list;
     }
 
     /**
@@ -93,6 +133,7 @@ class manip_sqlite
 
             $infos = array(
                 'type'=>    $parse['type'],
+                'pdo_type'=>$parse['pdo_type'],
                 'option'=>  $parse['option'],
                 'required'=>$this->parse_required($value['notnull']),
                 'effect'=>  array('RKT_validate', 'escape_character'),
@@ -100,7 +141,7 @@ class manip_sqlite
 
             /* プライマリキーは別扱い */
             if ($this->is_primary_key($value['pk'])){
-                $this->primary_key = array(
+                $this->primary = array(
                     'key'=>  $key,
                     'info'=> $infos
                 );
@@ -124,7 +165,8 @@ class manip_sqlite
      */
     function parse_type($subject,$field)
     {
-        $type = 'number';
+        $type = 'string';
+        $pdo_type = PDO_PARAM_STR;
         $option = null;
         $size = 8000;
         if (preg_match("/\d+/i",$subject,$matchs)){
@@ -139,6 +181,7 @@ class manip_sqlite
             );
         } else if (preg_match("/int/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
         } else if (preg_match("/text/i",$subject)){
             $type = 'string';
             $option = array(
@@ -156,16 +199,19 @@ class manip_sqlite
             );
         } else if (preg_match("/float/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/double/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/blob/i",$subject)){
             $type = 'string';
+            $pdo_type = PDO_PARAM_LOB;
             $option = array(
                 'max_length'=>$size
             );
@@ -176,6 +222,7 @@ class manip_sqlite
             $type = 'email';
         } else if (preg_match("/url/i",$field)){
             $type = 'uri';
+            $pdo_type = PDO_PARAM_STR;
         } else if (preg_match("/postal/i",$field)){
             $type = 'string';
             $option = array(
@@ -200,7 +247,7 @@ class manip_sqlite
             );
         }
         
-        return array('type'=>$type, 'option'=>$option);
+        return array('type'=>$type, 'pdo_type'=>$pdo_type, 'option'=>$option);
     }
 
     /**
