@@ -197,7 +197,13 @@ class RKT_mysql
         mysql_query($query, $this->dbh);
 		$this->sqlerror .= ob_get_contents();
 		ob_end_clean();
-        
+
+        if (!empty($this->sqlerror)){
+            $message = mysql_error($this->dbh);
+            error_log($this->sqlerror."\r\n", 3, ERROR_LOG_FILE);
+            error_log($message."\r\n", 3, ERROR_LOG_FILE);
+        }
+
         return @mysql_affected_rows($this->dbh);
     }
 
@@ -215,7 +221,11 @@ class RKT_mysql
 		$this->sqlerror .= ob_get_contents();
 		ob_end_clean();
 
-        $result = @mysql_query($query, $this->dbh);
+        if (!empty($this->sqlerror)){
+            $message = mysql_error($this->dbh);
+            error_log($this->sqlerror."\r\n", 3, ERROR_LOG_FILE);
+            error_log($message."\r\n", 3, ERROR_LOG_FILE);
+        }
         
         return ($result)?true:false;
     }
