@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/17] あしあと追加
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -56,6 +57,8 @@ class webapp extends WAP_community
         $this->set_topic();
         $this->set_event();
 
+        $this->doFootprint();
+
         $visibilitys = array(
             VISIBILITY_PUBLIC=>  VISIBILITY_LABEL_PUBLIC_ENTRY,
             VISIBILITY_PRIVATE=> VISIBILITY_LABEL_PRIVATE_ENTRY,
