@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/18] 一覧取得時の負荷軽減処置
  -      [2007/02/13] 公開フラグをビットフラグに対応
  -      [2006/07/27] 作成
  - ======================================================================== */
@@ -65,6 +66,12 @@ class webapp extends WAP_friend
      */
     var $where = '';
 
+    /**
+     * GROUP句
+     * @var string
+     */
+    var $group = '';
+
     /**
      * 公開設定
      * @var string
@@ -219,6 +226,11 @@ class webapp extends WAP_friend
             $where[] = 'sel.ref_category = '.$conditions['category'];
         }
 
+        /* GROUP BY */
+        if (!empty($this->table)){
+            $this->group = 'GROUP BY ent.id ';
+        }
+
         if (!count($where)){
             return '';
         }
@@ -302,18 +314,15 @@ class webapp extends WAP_friend
                 'ent.visibility as visibility,'.
                 'ent.subject as subject,'.
                 'ent.body as body,'.
-                'count(cmt.id) as comments '.
+                'ent.post as comments '.
             'FROM '.
                 DB_PREFIX.'dia_entry ent '.
-                'LEFT JOIN '.DB_PREFIX.'dia_comment cmt '.
-                    'ON ent.id = cmt.ref_entry '.
                 $this->table.
             'WHERE '.
                 'ent.ref_account = '.$this->ref_friend.' AND '.
                 sql_query::bitFlag('ent.visibility & '.$this->visibility).' '.
-                $this->where.
-            'GROUP BY '.
-                'ent.id '.
+                $this->where.' '.
+                $this->group.' '.
             'ORDER BY '.
                 'ent.regist_date DESC ';
         $objpgr->setSql($sql);
