@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/05] LEFT JOIN での条件指定を通常結合へ
  -      [2007/02/13] 公開フラグをビットフラグに対応
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -40,12 +41,24 @@ require_once WEBAPP_LIB_DIR.'wap_private.php';
  */
 class webapp extends WAP_private
 {
+    /**
+     * Table名
+     * @var string
+     */
+    var $table = '';
+
     /**
      * WHERE句
      * @var string
      */
     var $where = '';
 
+    /**
+     * Group By句
+     * @var string
+     */
+    var $group = '';
+
     /**
      * ORDER句
      * @var string
@@ -201,10 +214,12 @@ class webapp extends WAP_private
         /* アンケート */
         if (!empty($conditions['frm_select'])){
             if (is_array($conditions['frm_select'])){
-                $where[] = 'sel.ref_content in('.implode(',',$conditions['frm_select']).')';
+                $where[] = 'sel.ref_category in('.implode(',',$conditions['frm_select']).')';
             } else {
-                $where[] = 'sel.ref_content='.$conditions['frm_select'];
+                $where[] = 'sel.ref_category='.$conditions['frm_select'];
             }
+            $this->table = DB_PREFIX.'frm_select sel,';
+            $where[] = 'tpc.id = sel.ref_topic';
         }
         /* キーワード検索 */
         $keys = array();
@@ -218,6 +233,10 @@ class webapp extends WAP_private
             $where[] = '('.implode(' OR ',$keys) .') ';
         }
 
+        /* GROUP BY */
+        if (!empty($this->table)){
+            $this->group = 'GROUP BY tpc.id ';
+        }
 
         /* 並び替え */
         if (!empty($conditions['ref_sort'])){
@@ -279,9 +298,8 @@ class webapp extends WAP_private
                 'pro.nickname as nickname,'.
                 'sex.sex as sex '.
             'FROM '.
-                DB_PREFIX.'frm_topic tpc '.
-                    'LEFT JOIN '.DB_PREFIX.'frm_select sel '.
-                    'ON tpc.id = sel.ref_topic,'.
+                DB_PREFIX.'frm_topic tpc,'.
+                $this->table.
                 DB_PREFIX.'act_sex sex,'.
                 DB_PREFIX.'act_account act,'.
                 DB_PREFIX.'act_profile pro '.
@@ -291,9 +309,8 @@ class webapp extends WAP_private
                 'act.id = pro.ref_account AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 sql_query::bitFlag('tpc.visibility & '.VISIBILITY_OPEN).' '.
-                $this->where.
-            'GROUP BY '.
-                'tpc.id '.
+                $this->where.' '.
+                $this->group.' '.
                 $this->order;
         $objpgr->setSql($sql);
 
