@@ -57,8 +57,8 @@ class webapp extends WAP_private
 
         $this->setTemplateFile('private/diary/comments.tpl');
 
-        /* URL引数の取得 */
-        $this->setSafety('ref_entry');
+        /* PathInfo引数の取得 */
+        $this->setPathInfo('ref_entry');
         $this->Assign('ref_entry', $this->ref_entry);
 
         /* メニューオブジェクトの生成 */
