@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] 登録済みユーザー判定を追加
  -      [2007/01/21] テーブルを fri_friends から fri_invite に変更
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -157,22 +158,21 @@ class webapp extends WAP_public
     {
         $email = $this->objvld->getRequest('email');
         $email_hash = sql_query::hash($email);
+
         $sql=
             'SELECT '.
-                'id '.
+                'id,'.
+                'ref_friend '.
             'FROM '.
                 DB_PREFIX.'fri_invite '.
             'WHERE '.
-                'ref_account = '.SNS_ACC_GHOST.' AND '.
                 'email_hash ='.$this->objdb->quote($email_hash);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
-        $stmt->closeCursor();
 
-        $this->id = empty($result['id'])?0:$result['id'];
-        
-        return empty($this->id);
+        $this->id         = empty($result['id'])?0:$result['id'];
+        $this->ref_friend = empty($result['ref_friend'])?0:$result['ref_friend'];
     }
 
     /**
@@ -187,6 +187,13 @@ class webapp extends WAP_public
             return false;
         }
         $email = $this->objvld->getRequest('email');
+        $this->set_curid();
+
+        /* 既に登録されている */
+        if (!empty($this->ref_friend)){
+            $this->Assign('is_member', true);
+            return false;
+        }
 
         $encrypted  = sql_query::encrypt($email);
         $email_hash = sql_query::hash($email);
@@ -199,7 +206,7 @@ class webapp extends WAP_public
         $this->Assign('noupdate', true);
         
         $result = false;
-        if ($this->set_curid()){
+        if (empty($this->id)){
             $result = $this->insert_invite($values);
         } else {
             $result = $this->update_invite($values);
