@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/05] 絵文字コンバート処理修正
  -      [2007/05/27] フロントコントローラー名をexecへ変更
  -      [2007/05/27] セッションハンドラの設定をFCに移動
  -      [2006/09/21] .htaccess、PathInfoに依存しない処理を追加
@@ -62,6 +63,10 @@ ini_set('session.cookie_lifetime',0);                               // セッシ
 ini_set('session.use_cookies',0);                                   // セッション用クッキーの使用
 define('SESSION_ID_PREFIX', 'RKT');                                 // セッションキーの接頭語
 
+mb_substitute_character('long');                                    // 置き換え文字設定（入力フォーム変換時）
+
+/* 絵文字処理 */
+include_once LIB_DIR.'rkt_emoji.php';
 /**
  * [アウトプットフィルタ]
  * 文字エンコードの変換
@@ -72,7 +77,16 @@ define('SESSION_ID_PREFIX', 'RKT');                                 // セッシ
  */
 function tpl_utf2sjis($tpl_output, &$smarty)
 {
-    return mb_convert_encoding($tpl_output, 'SJIS', 'UTF-8');
+    $objemoji = new RKT_emoji();
+    $to = $objemoji->getFromEncoding();
+
+    /* 入力フォームからの絵文字変換用 */
+    $tpl_output = $objemoji->convert($tpl_output, $to, $to);
+
+    /* テンプレートファイル等の文字コードと絵文字変換 */
+    $tpl_output = $objemoji->convertEncoding($tpl_output, $to, 'Tag');
+
+    return $tpl_output;
 }
 
 } // (!defined('_WAP_CONFIG_PHP_'));
