@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/23] CHUNK文字数を追加
  -      [2007/07/07] SMTPの設定を追加
  -      [2007/07/05] Smarty設定ディレクトリパスの変更
  -      [2007/06/17] アクセス権限定義を追加
@@ -400,6 +401,7 @@ define('RKT_TBL_ACCOUNT',DB_PREFIX.'act_account');                  // アカウ
 define('RKT_TBL_AUTOLOGIN',DB_PREFIX.'act_autologin');              // 自動ログインテーブル名
 define('RKT_TBL_SESSION',DB_PREFIX.'sys_sessions');                 // セッションのテーブル名
 define('RKT_TBL_BLOB',DB_PREFIX.'sys_blob');                        // Binary Large OBjectテーブル名
+define('RKT_CHUNK_NUMBER', 18);                                     // CHUNK文字数
 
 define('BLOB_PARAM', RKT_BLOB_DSN);                                 // BLOB用引数
 
