@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/24] 過去の日付指定を追加
  -      [2007/06/16] 日記の公開レベルを追加
  -      [2007/03/11] 本文の入力データのエスケープ処理を変更
  -      [2007/02/02] 本文の初期値、改行部分を修正
@@ -154,6 +155,7 @@ class webapp extends WAP_private
         $objmenu->setMenu($this->account['id']);
 
         $this->set_category();
+        $this->set_date();
         $this->Assign('picture', $objpic->getImgInfos());
 
         $visibilitys = array(
@@ -165,6 +167,29 @@ class webapp extends WAP_private
         $this->Assign('visibilitys', $visibilitys);
 
         $this->setEmojiInit();
+        $this->setcCtegoryInit();
+    }
+
+    /**
+     * カテゴリ用の初期化設定
+     *
+     * @access public
+     * @return void
+     */
+    function setcCtegoryInit()
+    {
+        $init = 
+            'YAHOO.namespace("category.container");'."\r\n".
+            "\r\n".
+            'function init2() {'."\r\n".
+                'YAHOO.category.container.panel = new YAHOO.widget.Panel("category_table", { width:"240px", visible:false, constraintoviewport:true } );'."\r\n".
+                'YAHOO.category.container.panel.render();'."\r\n".
+                "\r\n".
+                'YAHOO.util.Event.addListener("category", "click", YAHOO.category.container.panel.show, YAHOO.category.container.panel, true);'."\r\n".
+            '}'."\r\n".
+            "\r\n".
+            'YAHOO.util.Event.addListener(window, "load", init2);';
+        $this->base['javascript'] .= $init;
     }
 
     /**
@@ -222,6 +247,44 @@ class webapp extends WAP_private
         }
     }
 
+    /**
+     * 日付の設定
+     *
+     * @return void
+     **/
+    function set_date()
+    {
+    	$years = array();
+    	$months = array();
+    	$days = array();
+
+    	$max_year = date('Y');
+    	for ($num=$max_year-4;$num<=$max_year;$num++) {
+    		$years[$num] = $num;
+    	}
+    	for ($num=1;$num<=12;$num++) {
+            $num = sprintf('%02d',$num);
+    		$months[$num] = $num;
+    	}
+    	for ($num=1;$num<=31;$num++) {
+            $num = sprintf('%02d',$num);
+    		$days[$num] = $num;
+    	}
+        $this->Assign('years', $years);
+        $this->Assign('months', $months);
+        $this->Assign('days', $days);
+
+        $now_date = date('Y-m-d H:i:s');
+
+        /* 開始年月日: */
+        $date = $this->objmnp->getValue('regist_date');
+        $date = empty($date)?$this->objmnp->getInitValue('regist_date'):$date;
+        $date = empty($date)?$now_date:$date;
+
+        $init_date = RKT_calendar::splitDate($date);
+        $this->Assign('regist_date', $init_date);
+    }
+
     /**
      * 日記IDの取得
      *
@@ -298,6 +361,23 @@ class webapp extends WAP_private
         $this->objmnp->setInitEffect('body', array('func'=>'nl2br'));
     }
 
+    /**
+     * 入力された日付が正当か？
+     *
+     * @access private
+     * @return boolean 正常時：真
+     */
+    function is_valid_term()
+    {
+        if (empty($_POST['regist_date'])){
+            return true;
+        }
+        $regist_date = RKT_calendar::joinDate($_POST['regist_date']);
+        $regist_date = strtotime($regist_date);
+
+        return ($regist_date < time());
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -312,7 +392,11 @@ class webapp extends WAP_private
             $this->init_effect();
         } else {
             $this->objmnp->setValue('ref_account', $this->account['id']);
-            $this->objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
+        }
+
+        // 過去の日付かのチェック
+        if (!$this->is_valid_term()){
+            $this->objmnp->setAlert('error_term');
         }
 
         /* 直接入力 */
@@ -327,7 +411,6 @@ class webapp extends WAP_private
         /* 更新しない項目名 */
         $skip = array(
             'ref_account',
-            'regist_date',
             'link',
             'body',
         );
@@ -434,6 +517,9 @@ class webapp extends WAP_private
             $this->dia_select = empty($_SESSION['dia_select'])?array():$_SESSION['dia_select'];
             return ;
         }
+        if (preg_match('/(manip|confirm|edit)/i',$_SERVER['REQUEST_URI'])){
+            return ;
+        }
         
         $sql=
             'SELECT '.
