@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/05/28] 既存ユーザー判定エラーを修正
  -      [2007/03/11] 携帯用URLを追加
  -      [2007/01/21] テーブルを fri_friends から fri_invite に変更
  -      [2006/07/29] 作成
@@ -130,17 +131,19 @@ class webapp extends WAP_private
         $email_hash = sql_query::hash(@$_POST['email']);
         $sql=
             'SELECT '.
-                'ref_friend '.
+                'act.id as id '.
             'FROM '.
-                DB_PREFIX.'fri_invite '.
+                DB_PREFIX.'act_account act,'.
+                DB_PREFIX.'fri_invite inv '.
             'WHERE '.
+                'act.id = inv.ref_friend AND '.
                 "email_hash = '".$email_hash."'";
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
-        return !empty($result['ref_friend']);
+        return !empty($result['id']);
     }
 
     /**
