@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/20] XSS対応
  -      [2006/07/10] 作成
  - ======================================================================== */
 
@@ -43,6 +44,12 @@ class webapp extends WAP_private
      */
     var $objmnp = null;
 
+    /**
+     * キーワード
+     * @var integer
+     */
+    var $keyword = '';
+
     /**
      * 実行処理
      *
@@ -54,15 +61,16 @@ class webapp extends WAP_private
         RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));
 
         $this->setTemplateFile('private/home/home.tpl');
-        
-        $keyword = empty($_REQUEST['keyword'])?'':urlencode($_REQUEST['keyword']);
-        
+
+        /* URL引数の取得 */
+        $this->setSafety('keyword','_REQUEST','string');
+                
         if (isset($_REQUEST['diary'])){
-            header('Location: '.HTTP_ACTION.'friend/diary/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
+            header('Location: '.HTTP_ACTION.'friend/diary/result/'.WAP_URI_SEPARATOR.'keyword='.$this->keyword);
         } elseif (isset($_REQUEST['forum'])){
-            header('Location: '.HTTP_ACTION.'friend/forum/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
+            header('Location: '.HTTP_ACTION.'friend/forum/result/'.WAP_URI_SEPARATOR.'keyword='.$this->keyword);
         } else {
-            header('Location: '.HTTP_ACTION.'private/review/search/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
+            header('Location: '.HTTP_ACTION.'private/review/search/'.WAP_URI_SEPARATOR.'keyword='.$this->keyword);
         }
 
         exit();
