@@ -95,9 +95,9 @@ class webapp extends WAP_public
                 'com.ref_account as ref_account,'.
                 'pro.nickname as nickname,'.
                 'prf.prefecture as prefecture,'.
-                'pic.filename as as as src,'.
-                'pic.width as as as width,'.
-                'pic.height as as as height '.
+                'pic.filename as src,'.
+                'pic.width as width,'.
+                'pic.height as height '.
             'FROM '.
                 DB_PREFIX.'com_community com '.
                     'LEFT JOIN '.DB_PREFIX.'com_picture pic '.
