@@ -192,6 +192,7 @@ class webapp extends WAP_public
                 'sex.id = pro.ref_sex AND '.
                 'mrd.id = pro.ref_married AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
+                'pro.visibility = '.VISIBILITY_PUBLIC.' AND '.
                 'pro.ref_account = '.$this->ref_friend;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -199,8 +200,7 @@ class webapp extends WAP_public
         $stmt->closeCursor();
         
         if (empty($result)){
-            header('Location: '.HTTP_ACTION);
-            exit();
+            return ;
         }
         
         $this->Assign('profile',$result);
