@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/01] 絵文字用ウインドウデザインの追加
  -      [2006/09/30] コメントの誤字を修正
  -      [2006/09/29] 基礎URLの初期値自動入力追加と説明を変更
  -      [2006/09/29] モジュール等の読み込み内容を修正
@@ -78,6 +79,12 @@ class webapp
      */
     var $buffer = '';
 
+    /**
+     * ファイル情報格納
+     * @var array
+     */
+    var $fileinfos = array();
+
     /**
      * 実行処理
      *
@@ -450,14 +457,78 @@ class webapp
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         
+        $this->copy_image($result['ref_common'],'top');
+        $this->copy_image($result['ref_common'],'header');
+        $this->copy_image($result['ref_common'],'common');
         $this->update_css($result['ref_common'],'common');
+        $this->update_css($result['ref_common'],'common','yui_container');
+
+        $this->copy_image($result['ref_admin'],'admin');
         $this->update_css($result['ref_admin'],'admin');
+
+        $this->copy_image($result['ref_private'],'private');
         $this->update_css($result['ref_private'],'private');
+
+        $this->copy_image($result['ref_friend'],'friend');
         $this->update_css($result['ref_friend'],'friend');
+
+        $this->copy_image($result['ref_community'],'community');
         $this->update_css($result['ref_community'],'community');
+
+        $this->copy_image($result['ref_public'],'public');
         $this->update_css($result['ref_public'],'public');
     }
 
+    /**
+     * 画像のコピー
+     *
+     * @access private
+     * @param integer $id
+     * @param string $target
+     * @return void
+     */
+    function copy_image($id, $target)
+    {
+        $sort_func = array(
+            'private'=>   'sort',
+            'friend'=>    'rsort',
+            'community'=> 'sort',
+            'header'=>    'sort',
+            'admin'=>     'rsort',
+        );
+
+        $dir = THEME_DIR.$id.DIRECTORY_SEPARATOR;
+        $prefix = '{'.$target.'_,joker_}';
+        if ($target === 'common'){
+            $prefix = 'common_';
+        } elseif ($target === 'top'){
+            $prefix = 'top_';
+        } elseif ($target === 'header'){
+            $prefix = 'header_';
+        }
+        $files = glob($dir.$prefix.'{*.jpg,*.jpeg,*.gif}', GLOB_BRACE);
+        eval($sort_func[$target].'($files);');
+
+        $img_path = RESOURCE_DIR.'img'.DIRECTORY_SEPARATOR.$target.DIRECTORY_SEPARATOR;
+
+        $infos = array();
+        foreach ($files as $source){
+            $file  = basename($source);
+            $name  = preg_replace('/(^'.$target.'_|joker_)/','',$file);
+            $split = explode('.', $name);
+            copy($source, $img_path.$name);
+            
+            $size = getimagesize($img_path.$name);
+            $infos[$split[0]] = array(
+                'filename'=>  $target.'/'.$name,
+                'extension'=> $split[1],
+                'width'=>     $size[0],
+                'height'=>    $size[1],
+            );
+        }
+        $this->fileinfos[$target] = $infos;
+    }
+
     /**
      * アンチエイリアス色の取得
      *
@@ -501,6 +572,35 @@ class webapp
         return $colors;
     }
 
+    /**
+     * 色の計算
+     *
+     * @access private
+     * @param string $color
+     * @param integer $number
+     * @return $color
+     */
+    function add_color($color, $number)
+    {
+        $red   = hexdec(substr($color, 0, 2));
+        $green = hexdec(substr($color, 2, 2));
+        $blue  = hexdec(substr($color, 4, 2));
+
+        $red   += $number;
+        $green += $number;
+        $blue  += $number;
+
+        $red   = ($red > 255)?255:$red;
+        $green = ($green > 255)?255:$green;
+        $blue  = ($blue > 255)?255:$blue;
+
+        $red   = ($red < 0)?0:$red;
+        $green = ($green < 0)?0:$green;
+        $blue  = ($blue < 0)?0:$blue;
+
+        return dechex($red).dechex($green).dechex($blue);
+    }
+
     /**
      * テキスト色の取得
      *
@@ -533,11 +633,12 @@ class webapp
      * @access private
      * @param integer $id
      * @param string $css
-     * @param string $frame_width
+     * @param string $filename
      * @return void
      */
-    function update_css($id,$css,$frame_width='800')
+    function update_css($id,$css,$filename='')
     {
+        $filename = empty($filename)?$css:$filename;
         $sql=
             'SELECT '.
                 '* '.
@@ -565,7 +666,6 @@ class webapp
         $colors = $this->anti_alias($result['box']);
         $smarty->assign('box', $colors);
 
-        $smarty->assign('frame_width', $frame_width);
         $smarty->assign('border', $result['border']);
         $smarty->assign('text', $result['text']);
         $smarty->assign('column', $result['column']);
@@ -575,12 +675,18 @@ class webapp
         $smarty->assign('background', $result['background']);
         $smarty->assign('copyright', $this->get_text_color($result['header']));
 
+        $smarty->assign('bg_column',  $this->add_color($result['border'], 50));
+        $smarty->assign('bg_title',   $this->add_color($result['box'],    40));
+        $smarty->assign('bg_subject', $this->add_color($result['border'], 60));
+        $smarty->assign('bg_list',    $this->add_color($result['background'], 25));
 
-        $output = $smarty->fetch('admin/design/css/'.$css.'.tpl');
+        $smarty->assign('fileinfo', $this->fileinfos);
+
+        $output = $smarty->fetch('admin/design/css/'.$filename.'.tpl');
         $output = mb_convert_encoding($output, 'SJIS', ENCODE_TYPE);
 
         /* ファイルの読み込み */
-        $filename = RESOURCE_DIR.'css'.DIRECTORY_SEPARATOR.$css.'.css';
+        $filename = RESOURCE_DIR.'css'.DIRECTORY_SEPARATOR.$filename.'.css';
         $fp = fopen($filename, 'w');
         if (!$fp){
             return ;
